pub struct CreateServerMountOptions {
pub server_uuid: Uuid,
pub mount_uuid: Uuid,
}Fields
server_uuid: Uuidmount_uuid: UuidTrait Implementations
Sourceimpl Validate for CreateServerMountOptions
impl Validate for CreateServerMountOptions
Sourcefn validate_into(
&self,
__garde_user_ctx: &Self::Context,
__garde_path: &mut dyn FnMut() -> Path,
__garde_report: &mut Report,
)
fn validate_into( &self, __garde_user_ctx: &Self::Context, __garde_path: &mut dyn FnMut() -> Path, __garde_report: &mut Report, )
Validates
Self, aggregating all validation errors into Report.fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read morefn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
fn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read moreAuto Trait Implementations
impl Freeze for CreateServerMountOptions
impl RefUnwindSafe for CreateServerMountOptions
impl Send for CreateServerMountOptions
impl Sync for CreateServerMountOptions
impl Unpin for CreateServerMountOptions
impl UnwindSafe for CreateServerMountOptions